@@ -1,3 +1,6 @@
+import re
+import tempfile
+import tika
 import os
 import shutil
 import openpyxl
@@ -5,7 +8,6 @@ import numpy as np
 import itertools
 import math
 import glob
-# import zipfile
 from tika import parser
 from openpyxl.worksheet.datavalidation import DataValidation
 from openpyxl.utils import get_column_letter
@@ -22,7 +24,8 @@ from jinjafy.plot.plot_helpers import get_colors
 import time
 from collections import defaultdict
 import zipfile
-
+import pandas as pd
+from slider.slide import recursive_tex_collect
 
 def get_dirs(zf):
     zip = zipfile.ZipFile(zf)
@@ -32,13 +35,11 @@ def get_dirs(zf):
 
 def fix_handins_fuckup(project_id=2):
     """ Handle the problem with multiple hand-ins in DTU learn. """
-    import zipfile
     paths = get_paths()
     from coursebox.core.info import class_information
     info = class_information()
     zf = paths['instructor_project_evaluations'] + f"/zip{project_id}.zip"
 
-
     tas = [i['shortname'] for i in info['instructors'] ]
     ta_links = {i['shortname']: i for i in info['instructors']}
 
@@ -51,7 +52,6 @@ def fix_handins_fuckup(project_id=2):
             ta_reports[r] = ta
 
     fls = get_dirs(zf)
-
     # fls = [f for f in zip.namelist() if not f.endswith("tml") and f.endswith("/")]
     d = defaultdict(lambda: [])
     for l in fls:
@@ -123,7 +123,6 @@ def handle_projects(verbose=False, gather_main_xlsx_file=True, plagiarism_check=
     zip1 = instructor_path + "/zip1.zip"
     zip2 = instructor_path + "/zip2.zip"
     zip3 = instructor_path + "/zip3.zip"
-
     zips = [None, zip1, zip2, zip3]
 
     for j,zf in enumerate(zips):
@@ -138,12 +137,12 @@ def handle_projects(verbose=False, gather_main_xlsx_file=True, plagiarism_check=
             continue
         else: # instructor files do not exist
             if j == 0:
-                copy_populate_from_template(info, sheet_number=j, zip_file=None)
+                copy_populate_from_template(paths, info, sheet_number=j, zip_file=None)
 
             elif os.path.exists(zf):
                 # make a copy of report template and populate it with groups obtained from previous report evaluation.
                 # all_groups = get_all_reports_from_collected_xlsx_file()
-                copy_populate_from_template(info, sheet_number=j, zip_file=zf)
+                copy_populate_from_template(paths, info, sheet_number=j, zip_file=zf)
                 # distribute_zip_content(info, sheet=j, zf_base=zf)
             else:
                 print("When available, please move downloaded copy of all reports from campusnet to destination:")
@@ -228,13 +227,13 @@ def compute_error_files(info, paths):
                         es = err_label + f"> Report score is {g.get('score', 0)}. The report score has to be between 0 and 4; probably due to a too high value of 'Delta' in instructor sheet."
                         ERRORS[ins].append(es)
 
-                if repn >= 1 and not g['comments']:
+                if repn >= 1 and not g['comments'] and info['course_number'] != '02465':
                     es = err_label + "> Incomplete report evaluation (missing comments field)"
                     es += "Please fill out comments field in your excel sheet."
                     ERRORS[ins].append(es)
 
 
-                if repn >= 1 and not g['approver_comments']:
+                if repn >= 1 and not g['approver_comments']  and info['course_number'] != '02465':
                     es = err_label + "> Incomplete report evaluation (you are missing the approver comments field; can simply be set to 'ok')."
                     ERRORS.get(g['approver'], []).append(es)
 
@@ -300,10 +299,92 @@ def get_instructor_xlsx_files(info, sheet):
     return xlsx
 
 
-import hashlib
+def get_groups_from_learn_xslx_file(paths, sheet_number):
+    fname = f"{paths['instructor_project_evaluations']}/groups{sheet_number}.xlsx"
+    all_groups = []
+    if os.path.exists(fname):
+        # Reading from the groups{number}.xlsx group-id file exported from DTU learn. Note this file contains fuckups.
+        dg = defaultdict(list)
+        df = pd.read_excel(fname)
+        for uname, group_id in zip(df['Username'], df['Project groups']):
+            id = int(group_id.split(" ")[1])
+            if len(uname) == 7 and uname[0] == 's':
+                dg[id].append(uname)
+            else:
+                dg[id].append("DTU-LEARN-FUCKED-THIS-ID-UP-CHECK-ON-REPORT")
+
+        all_groups = [{'group_id': id, 'student_ids': students} for id, students in dg.items()]
+    return all_groups
+
+
+def group_id_from_file(file):
+    id = int(os.path.dirname(file).split(" - ")[1].split(" ")[1])
+    return id
+
+def search_projects(paths, sheet_number, patterns):
+    zip_files = [paths['instructor_project_evaluations'] + "/zip%d.zip" % sheet_number]
+    # print(zip_files)
+
+    all_groups = []
+    gps = defaultdict(list)
+    for zip_file in zip_files:
+        if os.path.exists(zip_file):
+            tmpdir = tempfile.TemporaryDirectory()
+            zipfile.ZipFile(zip_file).extractall(path=tmpdir.name)
+
+            # Read from PDF files:
+            pdfs = glob.glob(tmpdir.name + "/**/*.pdf", recursive=True)
+            for pdf in pdfs:
+                pdf_parsed = tika.parser.from_file(pdf)
+                id =group_id_from_file(pdf) # int(os.path.dirname(pdf).split(" - ")[1].split(" ")[1])
+                if pdf_parsed['content'] is None:
+                    students = []
+                    print("> Finding student ID. Warning: The pdf file", pdf, "appers to have no text content.")
+                else:
+                    students = re.findall('s\d\d\d\d\d\d', pdf_parsed['content'], flags=re.IGNORECASE)
+                gps[id] += students
+
+            # Collect from .tex files:
+
+            # recursive_tex_collect()
+            texs = glob.glob(tmpdir.name + "/**/*.tex", recursive=True)
+            for tex in texs:
+                id = group_id_from_file(tex)
+                tex_parsed = recursive_tex_collect(tex)
+                tex_parsed = "\n".join([(l[:l.find("%")] if "%" in l else l) for l in tex_parsed.splitlines()])
+                students = re.findall('s\d\d\d\d\d\d', tex_parsed, flags=re.IGNORECASE)
+                gps[id] += students
+
+    for id, students in gps.items():
+        all_groups.append({'group_id': id, 'student_ids': list(set(students))})
+    return all_groups
+
+
+def unpack_zip_file_recursively(zip_file, destination_dir):
+    """
+    Unpack the zip_file (extension: .zip) to the given directory.
+
+    If the folders in the zip file contains other zip/files, these are unpacked recursively.
+    """
+    # Unpack zip file recursively and flatten it.
+    zipfile.ZipFile(zip_file).extractall(path=destination_dir)
+    ls = glob.glob(destination_dir + "/*")
+    for f in ls:
+        if os.path.isdir(f):
+            zipfiles = glob.glob(f + "/*.zip")
+            for zp in zipfiles:
+                print("Unpacking student zip file>", zp)
+                zipfile.ZipFile(zp).extractall(path=os.path.dirname(zp) + "/")
+
+
+def copy_populate_from_template(paths, info, sheet_number,zip_file):
+    # Try to load group ids from the project pdf's
+    all_groups = search_projects(paths, sheet_number, r"s\d{6}")
+    # all_groups = get_groups_from_learn_xslx_file(paths, sheet_number)
+    if len(all_groups) == 0:
+        all_groups = projects_info.get_groups_from_report(repn=sheet_number-1) if sheet_number > 0 else []
+    # Hopefully this did the trick and we have the groups all grouped up.
 
-def copy_populate_from_template(info, sheet_number,zip_file):
-    all_groups = projects_info.get_groups_from_report(repn=sheet_number-1) if sheet_number > 0 else []
     # set up which TA approve which TA
     if any( [i['language'] not in ["en", "any"] for i in info['instructors'] ]):
         print(info['instructors'])
@@ -337,10 +418,13 @@ def copy_populate_from_template(info, sheet_number,zip_file):
     n_groups_per_instructor = 24 + (sheet_number == 0) * 26
 
     if sheet_number > 0:
-        zfd = zip_file[:-4]
-        if not os.path.exists(zfd):
-            os.mkdir(zfd)
-        zipfile.ZipFile(zip_file).extractall(path=zfd)
+        # zfd = zip_file[:-4]
+        # if not os.path.exists(zfd):
+        #     os.mkdir(zfd)
+        zfd = tempfile.TemporaryDirectory().name
+        # zipfile.ZipFile(zip_file).extractall(path=tmpdir.name)
+
+        unpack_zip_file_recursively(zip_file, destination_dir=zfd)
         # get all report handins (i.e. directories)
         ls = [l for l in glob.glob(zfd + "/*") if l[-3:] not in ["txt", "tml"]]
 
@@ -431,8 +515,8 @@ def copy_populate_from_template(info, sheet_number,zip_file):
         corrector = all_tas[shortname]['approver']
         if sheet_number > 0:
             # Copy reports to directory (distribute amongst TAs)
-            b_dir = os.path.dirname(zip_file)
-            ins_dir = "%s/project_%i_%s/"%(b_dir, sheet_number, shortname)
+            # b_dir = os.path.dirname(zip_file)
+            ins_dir = "%s/project_%i_%s/"%(zfd, sheet_number, shortname)
 
             if not os.path.exists(ins_dir):
                 os.mkdir(ins_dir)
@@ -440,7 +524,7 @@ def copy_populate_from_template(info, sheet_number,zip_file):
             for handin in all_tas[shortname]['handins']:
                 shutil.move(handin['path'], ins_dir)
 
-            shutil.make_archive(ins_dir[:-1], 'zip', ins_dir)
+            shutil.make_archive(os.path.dirname(zip_file) +"/"+ os.path.basename(ins_dir[:-1]), 'zip', ins_dir)
             time.sleep(2)
             print("Removing tree of reports to clear up space...")
             shutil.rmtree(ins_dir)
@@ -471,10 +555,10 @@ def copy_populate_from_template(info, sheet_number,zip_file):
                         sheet.cell(STUDENT_ID_ROW+j, ccol+i).value = s
         wb.save(ifile)
         wb.close()
-    # clean up zip file directories
-    if sheet_number > 0:
-        zfd = zip_file[:-4]
-        shutil.rmtree(zfd)
+    # clean up zip file directories; since it is a tmp file, we don't have to.
+    # if sheet_number > 0:
+    #     zfd = zip_file[:-4]
+    #     shutil.rmtree(zfd)
 
 def write_dropdown_sumprod_sheet(sheet):
     ccol = 2
