@@ -4,7 +4,7 @@ from datetime import datetime, timedelta
 import calendar
 import pickle
 import time
-from line_profiler_pycharm import profile
+# from line_profiler_pycharm import profile
 from coursebox.thtools_base import partition_list
 
 import slider
@@ -233,7 +233,7 @@ from pathlib import Path
 
 from jinjafy.cache.simplecache import hash_file_
 
-@profile
+# @profile
 def get_hash_from_base(base):
     if not os.path.exists(base + "/sharedcache.pkl"):
         source = {}
@@ -263,7 +263,7 @@ def get_hash_from_base(base):
     return actual_files
 
 
-@profile
+# @profile
 def fix_shared(paths, output_dir, pdf2png=False,dosvg=True,verbose=False, compile_templates=True,shallow=True):
     '''
     Copy shared files into lecture directories
@@ -290,7 +290,7 @@ def fix_shared(paths, output_dir, pdf2png=False,dosvg=True,verbose=False, compil
     source_extra = {}
     for rel in source:
         if rel.endswith(".svg") and source[rel]['modified']:
-            pdf_file = svg2pdf(shared_base + "/"+rel, crop=True, text_to_path=True, verbose=True)
+            pdf_file = svg2pdf(shared_base + "/"+rel, crop=True, text_to_path=True)
             rel = os.path.relpath(pdf_file, shared_base)
             source_extra[rel] = dict(mtime=os.path.getmtime(pdf_file), hash=hash_file_(pdf_file), modified=True)
 
@@ -551,7 +551,7 @@ def mvfiles(source_dir, dest_dir):
         if (os.path.isfile(full_file_name)):
             shutil.copy(full_file_name, os.path.dirname(dest_dir))
 
-@profile
+# @profile
 def make_webpage(dosvg=True):
     cinfo = class_information()
     paths = get_paths()
